package cn.iocoder.yudao.module.jx.mapper;

import cn.iocoder.yudao.module.jx.domain.DriveSchoolCredentials;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 驾校资质信息Mapper接口
 *
 * @author ruoyi
 * @date 2024-05-23
 */
@Mapper
public interface DriveSchoolCredentialsMapper
{
    /**
     * 查询驾校资质信息
     *
     * @param id 驾校资质信息主键
     * @return 驾校资质信息
     */
    public DriveSchoolCredentials selectDriveSchoolCredentialsById(Long id);

    /**
     * 查询驾校资质信息列表
     *
     * @param driveSchoolCredentials 驾校资质信息
     * @return 驾校资质信息集合
     */
    public IPage<DriveSchoolCredentials> selectDriveSchoolCredentialsList(@Param("entity") DriveSchoolCredentials driveSchoolCredentials, Page<DriveSchoolCredentials> page);

    /**
     * 新增驾校资质信息
     *
     * @param driveSchoolCredentials 驾校资质信息
     * @return 结果
     */
    public int insertDriveSchoolCredentials(DriveSchoolCredentials driveSchoolCredentials);

    /**
     * 修改驾校资质信息
     *
     * @param driveSchoolCredentials 驾校资质信息
     * @return 结果
     */
    public int updateDriveSchoolCredentials(DriveSchoolCredentials driveSchoolCredentials);

    /**
     * 删除驾校资质信息
     *
     * @param id 驾校资质信息主键
     * @return 结果
     */
    public int deleteDriveSchoolCredentialsById(Long id);

    /**
     * 批量删除驾校资质信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDriveSchoolCredentialsByIds(Long[] ids);
}
